@@ -1,29 +1,14 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2010 Miha Čančula <miha.cancula@gmail.com>
-    Copyright (C) 2019 Alexander Semke <alexander.semke@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2010 Miha Čančula <miha.cancula@gmail.com>
+    SPDX-FileCopyrightText: 2019 Alexander Semke <alexander.semke@web.de>
 */
 
 #include "octavebackend.h"
 #include "octaveextensions.h"
 #include "octavesession.h"
+#include "octavesettingswidget.h"
 #include "settings.h"
-#include "ui_settings.h"
 
 OctaveBackend::OctaveBackend(QObject* parent, const QList<QVariant>& args): Backend(parent, args)
 {
@@ -87,10 +72,7 @@ QString OctaveBackend::description() const
 
 QWidget* OctaveBackend::settingsWidget(QWidget* parent) const
 {
-    QWidget* widget = new QWidget(parent);
-    Ui::OctaveSettingsBase ui;
-    ui.setupUi(widget);
-    return widget;
+    return new OctaveSettingsWidget(parent, id());
 }
 
 KConfigSkeleton* OctaveBackend::config() const
