@@ -1,20 +1,7 @@
 /*
-    Copyright (C) 2010 Miha Čančula <miha.cancula@gmail.com>
+    SPDX-FileCopyrightText: 2010 Miha Čančula <miha.cancula@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "octaveexpression.h"
@@ -139,6 +126,11 @@ QString OctaveExpression::internalCommand()
         if (status != 3)
             tmp += cmd[i];
     }
+
+    //Remove "\n" in the beginning of the command, if present
+    while(tmp[0] == QLatin1Char('\n'))
+        tmp.remove(0, 1);
+
     cmd = tmp;
     cmd.replace(QLatin1String(";\n"), QLatin1String(";"));
     cmd.replace(QLatin1Char('\n'), QLatin1Char(','));
