@@ -1,26 +1,12 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2012 Filipe Saraiva <filipe@kde.org>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012 Filipe Saraiva <filipe@kde.org>
+*/
 
 #include "pythonbackend.h"
 #include "pythonsession.h"
 #include "pythonextensions.h"
+#include "pythonsettingswidget.h"
 #include "settings.h"
 #include "ui_settings.h"
 
@@ -40,10 +26,7 @@ PythonBackend::PythonBackend(QObject* parent, const QList<QVariant>& args) : Can
 
 QWidget* PythonBackend::settingsWidget(QWidget* parent) const
 {
-    QWidget* widget=new QWidget(parent);
-    Ui::PythonSettingsBase s;
-    s.setupUi(widget);
-    return widget;
+    return new PythonSettingsWidget(parent, id());
 }
 
 Cantor::Session* PythonBackend::createSession()
