@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+*/
 #include "cantor.h"
 #include "lib/session.h"
 
@@ -36,26 +21,28 @@
 #include <QApplication>
 #include <QCloseEvent>
 #include <QDebug>
-#include <QDockWidget>
 #include <QDir>
+#include <QDockWidget>
 #include <QFileDialog>
-#include <QPushButton>
-#include <QRegularExpression>
 #include <QStatusBar>
 #include <QGraphicsView>
+#include <QPushButton>
+#include <QRegularExpression>
+
 
 #include "lib/backend.h"
 #include "lib/panelpluginhandler.h"
 #include "lib/panelplugin.h"
 #include "lib/worksheetaccess.h"
 
+#include "backendchoosedialog.h"
 #include "settings.h"
 #include "ui_settings.h"
 #include "ui_formating.h"
 #include "backendchoosedialog.h"
 #include <QMetaObject>
 
-CantorShell::CantorShell() : KParts::MainWindow(), m_part(nullptr), m_panelHandler(nullptr)
+CantorShell::CantorShell() : KParts::MainWindow(), m_tabWidget(new QTabWidget(this))
 {
     // set the shell's ui resource file
     setXMLFile(QLatin1String("cantor_shell.rc"));
@@ -65,7 +52,6 @@ CantorShell::CantorShell() : KParts::MainWindow(), m_part(nullptr), m_panelHandl
 
     createGUI(nullptr);
 
-    m_tabWidget=new QTabWidget(this);
     m_tabWidget->setTabsClosable(true);
     m_tabWidget->setMovable(true);
     m_tabWidget->setDocumentMode(true);
@@ -157,7 +143,7 @@ void CantorShell::setupActions()
 
     KStandardAction::preferences(this, SLOT(showSettings()), actionCollection());
 
-    QAction* downloadExamples = new QAction(i18n("Download Example Worksheets"), actionCollection());
+    QAction* downloadExamples = new QAction(i18n("Download Examples"), actionCollection());
     downloadExamples->setIcon(QIcon::fromTheme(QLatin1String("get-hot-new-stuff")));
     actionCollection()->addAction(QLatin1String("file_example_download"),  downloadExamples);
     connect(downloadExamples, &QAction::triggered, this,  &CantorShell::downloadExamples);
@@ -339,7 +325,7 @@ void CantorShell::addWorksheet(const QString& backendName)
     // this routine will find and load our Part.  it finds the Part by
     // name which is a bad idea usually.. but it's alright in this
     // case since our Part is made for this Shell
-    KPluginLoader loader(QLatin1String("cantorpart"));
+    KPluginLoader loader(QLatin1String("kf5/parts/cantorpart"));
     KPluginFactory* factory = loader.factory();
     if (factory)
     {
@@ -373,6 +359,7 @@ void CantorShell::addWorksheet(const QString& backendName)
             connect(part, SIGNAL(hierarhyEntryNameChange(QString, QString, int)), this, SIGNAL(hierarhyEntryNameChange(QString, QString, int)));
             connect(this, SIGNAL(requestScrollToHierarchyEntry(QString)), part, SIGNAL(requestScrollToHierarchyEntry(QString)));
             connect(this, SIGNAL(settingsChanges()), part, SIGNAL(settingsChanges()));
+            connect(part, SIGNAL(requestDocumentation(QString)), this, SIGNAL(requestDocumentation(QString)));
 
             m_parts.append(part);
             if (backend) // If backend empty (loading worksheet from file), then we connect to signal and wait
@@ -718,6 +705,7 @@ void CantorShell::initPanels()
         QDockWidget* docker = new QDockWidget(plugin->name(), this);
         docker->setObjectName(plugin->name());
         docker->setWidget(plugin->widget());
+        docker->setWindowIcon(QIcon::fromTheme(QStringLiteral("format-text-bold")));
         addDockWidget(Qt::RightDockWidgetArea, docker);
 
         docker->hide();
@@ -838,9 +826,6 @@ void CantorShell::updateNewSubmenu()
 Cantor::WorksheetAccessInterface* CantorShell::currentWorksheetAccessInterface()
 {
     auto* wa = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
-    if (!wa)
-        qDebug()<<"failed to access worksheet access interface for current part";
-
     return wa;
 }
 
@@ -870,7 +855,6 @@ void CantorShell::saveDockPanelsState(KParts::ReadWritePart* part)
 {
     if (m_parts2Backends.contains(part))
     {
-
         QStringList visiblePanelNames;
         if (part == m_part)
         {
@@ -909,7 +893,5 @@ void CantorShell::updateBackendForPart(const QString& backend)
 void CantorShell::pluginCommandRunRequested(const QString& cmd)
 {
     if (m_part)
-    {
         QMetaObject::invokeMethod(m_part, "runCommand", Qt::QueuedConnection, Q_ARG(QString, cmd));
-    }
 }
