@@ -1,23 +1,8 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
-    Copyright (C) 2017-2019 Alexander Semke <alexander.semke@web.de>
-    Copyright (C) 2019 Sirgienko Nikita <warquark@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2017-2021 Alexander Semke <alexander.semke@web.de>
+    SPDX-FileCopyrightText: 2019 Sirgienko Nikita <warquark@gmail.com>
 */
 
 #include <config-cantor.h>
@@ -29,8 +14,6 @@
 #include "lib/assistant.h"
 #include "lib/backend.h"
 #include "lib/extension.h"
-#include "lib/panelpluginhandler.h"
-#include "lib/panelplugin.h"
 #include "lib/worksheetaccess.h"
 #include "scripteditor/scripteditorwidget.h"
 #include "searchbar.h"
@@ -45,7 +28,8 @@
 #include <KNS3/UploadDialog>
 #include <KParts/GUIActivateEvent>
 #include <KPluginFactory>
-#include <KRun>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 #include <KStandardAction>
 #include <KToggleAction>
 #include <KSelectAction>
@@ -151,6 +135,8 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     connect(m_worksheet, &Worksheet::hierarhyEntryNameChange, this, &CantorPart::hierarhyEntryNameChange);
     connect(this, &CantorPart::requestScrollToHierarchyEntry, m_worksheet, &Worksheet::requestScrollToHierarchyEntry);
     connect(this, &CantorPart::settingsChanges, m_worksheet, &Worksheet::handleSettingsChanges);
+    connect(m_worksheet, &Worksheet::requestDocumentation, this, &CantorPart::requestDocumentation);
+
     layout->addWidget(m_worksheetview);
     setWidget(widget);
 
@@ -161,7 +147,7 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     //initialize actions
     auto* collection = actionCollection();
     connect(collection, &KActionCollection::inserted, m_worksheet, &Worksheet::registerShortcut);
-    m_worksheet->createActions(collection);
+    m_worksheet->setActionCollection(collection);
 
     KStandardAction::saveAs(this, SLOT(fileSaveAs()), collection);
     m_save = KStandardAction::save(this, SLOT(save()), collection);
@@ -354,11 +340,16 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     connect(removeCurrent, &QAction::triggered, m_worksheet, &Worksheet::removeCurrentEntry);
     m_editActions.push_back(removeCurrent);
 
+    Cantor::Backend* const backend = Cantor::Backend::getBackend(backendName);
     m_showBackendHelp = new QAction(i18n("Show Help") , collection);
-    m_showBackendHelp->setIcon(QIcon::fromTheme(QLatin1String("help-contents")));
+    m_showBackendHelp->setIcon(QIcon::fromTheme(backend->icon()));
     collection->addAction(QLatin1String("backend_help"), m_showBackendHelp);
     connect(m_showBackendHelp, &QAction::triggered, this, &CantorPart::showBackendHelp);
 
+    // Do not display "Show Backend Help" action for Maxima, since we are showing it's integrated documentation
+    if(backend->name() == QLatin1String("Maxima") || backend->name() == QLatin1String("Octave") || backend->name() == QLatin1String("Python"))
+        m_showBackendHelp->setVisible(false);
+
     // Disabled, because uploading to kde store from program don't work
     // See https://phabricator.kde.org/T9980 for details
     // If this situation will changed, then uncomment this action
@@ -754,11 +745,13 @@ void CantorPart::enableTypesetting(bool enable)
 
 void CantorPart::showBackendHelp()
 {
-    qDebug()<<"showing backends help";
+    qDebug()<<"Showing backend's help";
     auto* backend = m_worksheet->session()->backend();
     QUrl url = backend->helpUrl();
     qDebug()<<"launching url "<<url;
-    new KRun(url, widget());
+    auto *job = new KIO::OpenUrlJob(url);
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, widget()));
+    job->start();
 }
 
 Worksheet* CantorPart::worksheet()
@@ -840,7 +833,6 @@ void CantorPart::runAssistant()
 {
     Cantor::Assistant* a = qobject_cast<Cantor::Assistant*>(sender());
     QStringList cmds = a->run(widget());
-    qDebug()<<cmds;
     if(!cmds.isEmpty())
         runCommand(cmds.join(QLatin1String("\n")));
 }
@@ -968,15 +960,12 @@ void CantorPart::showScriptEditor(bool show)
     if(show)
     {
         if (m_scriptEditor)
-        {
             return;
-        }
 
         auto* scriptE = dynamic_cast<Cantor::ScriptExtension*>(m_worksheet->session()->backend()->extension(QLatin1String("ScriptExtension")));
         if (!scriptE)
-        {
             return;
-        }
+
         m_scriptEditor = new ScriptEditorWidget(scriptE->scriptFileFilter(), scriptE->highlightingMode(), widget()->window());
         connect(m_scriptEditor, &ScriptEditorWidget::runScript, this, &CantorPart::runScript);
         connect(m_scriptEditor, &ScriptEditorWidget::destroyed, this, &CantorPart::scriptEditorClosed);
@@ -1041,7 +1030,6 @@ void CantorPart::showImportantStatusMessage(const QString& message)
 void CantorPart::zoomValueEdited(const QString& text)
 {
     static const QRegularExpression zoomRegexp(QLatin1String("(?:(\\d+)%|(\\d+))"));
-
     QRegularExpressionMatch match = zoomRegexp.match(text);
     if (match.hasMatch())
     {
@@ -1066,6 +1054,5 @@ void CantorPart::updateZoomWidgetValue(double zoom)
     }
 }
 
-
 K_PLUGIN_FACTORY_WITH_JSON(CantorPartFactory, "cantor_part.json", registerPlugin<CantorPart>();)
 #include "cantor_part.moc"
