@@ -1,30 +1,14 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2012 martin Kuettler <martin.kuettler@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2012 martin Kuettler <martin.kuettler@gmail.com>
+*/
 
 #include "imageentry.h"
-#include "worksheetimageitem.h"
 #include "actionbar.h"
+#include "worksheetimageitem.h"
+#include "worksheetview.h"
 #include "lib/jupyterutils.h"
 
-#include <KLocalizedString>
-#include <QDebug>
 #include <QDir>
 #include <QMenu>
 #include <QFileSystemWatcher>
@@ -32,6 +16,9 @@
 #include <QJsonObject>
 #include <QStandardPaths>
 
+#include <KLocalizedString>
+#include <KZip>
+
 ImageEntry::ImageEntry(Worksheet* worksheet) : WorksheetEntry(worksheet)
 {
     m_imageItem = nullptr;
@@ -55,11 +42,13 @@ ImageEntry::ImageEntry(Worksheet* worksheet) : WorksheetEntry(worksheet)
 
 void ImageEntry::populateMenu(QMenu* menu, QPointF pos)
 {
-    menu->addAction(QIcon::fromTheme(QLatin1String("configure")), i18n("Configure Image"),
-                    this, SLOT(startConfigDialog()));
-    menu->addSeparator();
-
     WorksheetEntry::populateMenu(menu, pos);
+    auto* firstAction = menu->actions().at(0);
+
+    auto* action = new QAction(QIcon::fromTheme(QLatin1String("configure")), i18n("Configure Image"));
+    menu->insertAction(firstAction, action);
+    connect(action, &QAction::triggered, this, &ImageEntry::startConfigDialog);
+    menu->insertSeparator(firstAction);
 }
 
 bool ImageEntry::isEmpty()
@@ -180,12 +169,14 @@ QDomElement ImageEntry::toXml(QDomDocument& doc, KZip* archive)
     fileName.appendChild(fileNameText);
     image.appendChild(fileName);
     image.appendChild(path);
+
     QDomElement display = doc.createElement(QLatin1String("Display"));
     display.setAttribute(QLatin1String("width"), m_displaySize.width);
     display.setAttribute(QLatin1String("widthUnit"), unitNames[m_displaySize.widthUnit]);
     display.setAttribute(QLatin1String("height"), m_displaySize.height);
     display.setAttribute(QLatin1String("heightUnit"), unitNames[m_displaySize.heightUnit]);
     image.appendChild(display);
+
     QDomElement print = doc.createElement(QLatin1String("Print"));
     print.setAttribute(QLatin1String("useDisplaySize"), m_useDisplaySizeForPrinting);
     print.setAttribute(QLatin1String("width"), m_printSize.width);
@@ -245,10 +236,6 @@ QString ImageEntry::latexSizeString(const ImageSize& imgSize)
     return QLatin1String("[") + sizeString + QLatin1String("]");
 }
 
-void ImageEntry::interruptEvaluation()
-{
-}
-
 bool ImageEntry::evaluate(EvaluationOption evalOp)
 {
     evaluateNext(evalOp);
@@ -267,7 +254,7 @@ void ImageEntry::updateEntry()
 {
     qreal oldHeight = height();
     if (m_imagePath.isEmpty()) {
-        m_textItem->setPlainText(i18n("Right click here to insert image"));
+        m_textItem->setPlainText(i18n("Double click here to configure image settings"));
         m_textItem->setVisible(true);
         if (m_imageItem)
             m_imageItem->setVisible(false);
@@ -313,13 +300,11 @@ void ImageEntry::updateEntry()
             if (m_imagePath.endsWith(QLatin1String(".eps"), Qt::CaseInsensitive))
                 size /= worksheet()->renderer()->scale();
             m_imageItem->setSize(size);
-            qDebug() << size;
             m_textItem->setVisible(false);
             m_imageItem->setVisible(true);
         }
     }
 
-    qDebug() << oldHeight << height();
     if (oldHeight != height())
         recalculateSize();
 }
@@ -388,7 +373,6 @@ void ImageEntry::addActionsToBar(ActionBar* actionBar)
                          this, SLOT(startConfigDialog()));
 }
 
-
 void ImageEntry::layOutForWidth(qreal entry_zone_x, qreal w, bool force)
 {
     if (size().width() == w && m_textItem->pos().x() == entry_zone_x && !force)
@@ -418,3 +402,8 @@ bool ImageEntry::wantFocus()
 {
     return false;
 }
+
+void ImageEntry::mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
+{
+    startConfigDialog();
+}
