@@ -1,57 +1,22 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2009 Alexander Rieder <alexanderrieder@gmail.com>
-    Copyright (C) 2012 Martin Kuettler <martin.kuettler@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2012 Martin Kuettler <martin.kuettler@gmail.com>
+    SPDX-FileCopyrightText: 2018-2021 Alexander Semke <alexander.semke@web.de>
+*/
 
 #include "worksheet.h"
-
-#include <QtGlobal>
-#include <QApplication>
-#include <QBuffer>
-#include <QDebug>
-#include <QDrag>
-#include <QGraphicsWidget>
-#include <QPrinter>
-#include <QTimer>
-#include <QXmlQuery>
-#include <QJsonArray>
-#include <QJsonDocument>
-
-#include <KMessageBox>
-#include <KActionCollection>
-#include <KFontAction>
-#include <KFontSizeAction>
-#include <KToggleAction>
-#include <KLocalizedString>
-#include <QRegularExpression>
-#include <QElapsedTimer>
-
-#include "settings.h"
 #include "commandentry.h"
-#include "textentry.h"
-#include "markdownentry.h"
-#include "latexentry.h"
+#include "hierarchyentry.h"
+#include "horizontalruleentry.h"
 #include "imageentry.h"
+#include "latexentry.h"
+#include "markdownentry.h"
 #include "pagebreakentry.h"
 #include "placeholderentry.h"
-#include "horizontalruleentry.h"
-#include "hierarchyentry.h"
+#include "settings.h"
+#include "textentry.h"
+#include "worksheetview.h"
 #include "lib/jupyterutils.h"
 #include "lib/backend.h"
 #include "lib/extension.h"
@@ -61,35 +26,36 @@
 
 #include <config-cantor.h>
 
+#include <QApplication>
+#include <QBuffer>
+#include <QDrag>
+#include <QGraphicsSceneMouseEvent>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QPrinter>
+#include <QRegularExpression>
+#include <QTimer>
+#include <QXmlQuery>
+
+#include <KMessageBox>
+#include <KActionCollection>
+#include <KFontAction>
+#include <KFontSizeAction>
+#include <KToggleAction>
+#include <KLocalizedString>
+#include <KZip>
+
 const double Worksheet::LeftMargin = 4;
 const double Worksheet::RightMargin = 4;
 const double Worksheet::TopMargin = 12;
 const double Worksheet::EntryCursorLength = 30;
 const double Worksheet::EntryCursorWidth = 2;
 
-Worksheet::Worksheet(Cantor::Backend* backend, QWidget* parent, bool useDeafultWorksheetParameters)
-    : QGraphicsScene(parent)
+Worksheet::Worksheet(Cantor::Backend* backend, QWidget* parent, bool useDefaultWorksheetParameters)
+    : QGraphicsScene(parent),
+    m_cursorItemTimer(new QTimer(this)),
+    m_useDefaultWorksheetParameters(useDefaultWorksheetParameters)
 {
-    m_session = nullptr;
-
-    m_highlighter = nullptr;
-
-    m_firstEntry = nullptr;
-    m_lastEntry = nullptr;
-    m_lastFocusedTextItem = nullptr;
-    m_dragEntry = nullptr;
-    m_placeholderEntry = nullptr;
-    m_dragScrollTimer = nullptr;
-
-    m_choosenCursorEntry = nullptr;
-    m_isCursorEntryAfterLastEntry = false;
-
-    m_useDefaultWorksheetParameters = useDeafultWorksheetParameters;
-
-    m_viewWidth = 0;
-    m_maxWidth = 0;
-    m_maxPromptWidth = 0;
-
     m_entryCursorItem = addLine(0,0,0,0);
     const QColor& color = (palette().color(QPalette::Base).lightness() < 128) ? Qt::white : Qt::black;
     QPen pen(color);
@@ -97,18 +63,27 @@ Worksheet::Worksheet(Cantor::Backend* backend, QWidget* parent, bool useDeafultW
     m_entryCursorItem->setPen(pen);
     m_entryCursorItem->hide();
 
-    m_cursorItemTimer = new QTimer(this);
     connect(m_cursorItemTimer, &QTimer::timeout, this, &Worksheet::animateEntryCursor);
     m_cursorItemTimer->start(500);
 
-    m_jupyterMetadata = nullptr;
-
-    m_hierarchyMaxDepth = 0;
-
     if (backend)
         initSession(backend);
 }
 
+void Worksheet::stopAnimations()
+{
+    m_cursorItemTimer->stop();
+    m_entryCursorItem->hide();
+}
+
+void Worksheet::resumeAnimations()
+{
+    delete m_cursorItemTimer;
+    m_cursorItemTimer = new QTimer(this);
+    connect(m_cursorItemTimer, &QTimer::timeout, this, &Worksheet::animateEntryCursor);
+    m_cursorItemTimer->start(500);
+}
+
 Worksheet::~Worksheet()
 {
     m_isClosing = true;
@@ -521,23 +496,23 @@ WorksheetEntry* Worksheet::lastEntry()
 void Worksheet::setFirstEntry(WorksheetEntry* entry)
 {
     if (m_firstEntry)
-        disconnect(m_firstEntry, SIGNAL(aboutToBeDeleted()),
-                   this, SLOT(invalidateFirstEntry()));
+        disconnect(m_firstEntry, &WorksheetEntry::aboutToBeDeleted,
+                   this, &Worksheet::invalidateFirstEntry);
     m_firstEntry = entry;
     if (m_firstEntry)
-        connect(m_firstEntry, SIGNAL(aboutToBeDeleted()),
-                this, SLOT(invalidateFirstEntry()), Qt::DirectConnection);
+        connect(m_firstEntry, &WorksheetEntry::aboutToBeDeleted,
+                this, &Worksheet::invalidateFirstEntry, Qt::DirectConnection);
 }
 
 void Worksheet::setLastEntry(WorksheetEntry* entry)
 {
     if (m_lastEntry)
-        disconnect(m_lastEntry, SIGNAL(aboutToBeDeleted()),
-                   this, SLOT(invalidateLastEntry()));
+        disconnect(m_lastEntry, &WorksheetEntry::aboutToBeDeleted,
+                   this, &Worksheet::invalidateLastEntry);
     m_lastEntry = entry;
     if (m_lastEntry)
-        connect(m_lastEntry, SIGNAL(aboutToBeDeleted()),
-                this, SLOT(invalidateLastEntry()), Qt::DirectConnection);
+        connect(m_lastEntry, &WorksheetEntry::aboutToBeDeleted,
+                this, &Worksheet::invalidateLastEntry, Qt::DirectConnection);
 }
 
 void Worksheet::invalidateFirstEntry()
@@ -903,16 +878,6 @@ WorksheetEntry* Worksheet::insertLatexEntry(WorksheetEntry* current)
     return insertEntry(LatexEntry::Type, current);
 }
 
-void Worksheet::insertCommandEntry(const QString& text)
-{
-    WorksheetEntry* entry = insertCommandEntry();
-    if(entry&&!text.isNull())
-    {
-        entry->setContent(text);
-        evaluateCurrentEntry();
-    }
-}
-
 WorksheetEntry * Worksheet::insertHorizontalRuleEntry(WorksheetEntry* current)
 {
     return insertEntry(HorizontalRuleEntry::Type, current);
@@ -1104,8 +1069,8 @@ void Worksheet::enableHighlighting(bool highlight)
         if(!m_highlighter)
             m_highlighter=new Cantor::DefaultHighlighter(this);
 
+        //TODO: new syntax
         connect(m_highlighter, SIGNAL(rulesChanged()), this, SLOT(rehighlight()));
-
     }else
     {
         if(m_highlighter)
@@ -1467,18 +1432,11 @@ bool Worksheet::loadCantorWorksheet(const KZip& archive)
         m_readOnly = true;
     }
 
-    if (m_readOnly)
-    {
-        // TODO: Handle this here?
-        for (QAction* action : m_richTextActionList)
-            action->setEnabled(false);
-    }
-
     m_isLoadingFromFile = true;
 
     //cleanup the worksheet and all it contains
     delete m_session;
-    m_session=nullptr;
+    m_session = nullptr;
 
     //file can only be loaded in a worksheet that was not edited/modified yet (s.a. CantorShell::load())
     //in this case on the default "first entry" is available -> delete it.
@@ -1860,90 +1818,109 @@ void Worksheet::populateMenu(QMenu *menu, QPointF pos)
                 m_lastFocusedTextItem = item;
         }
 
-        if (!isRunning())
-            menu->addAction(QIcon::fromTheme(QLatin1String("system-run")), i18n("Evaluate Worksheet"),
-                            this, SLOT(evaluate()), 0);
-        else
-            menu->addAction(QIcon::fromTheme(QLatin1String("process-stop")), i18n("Interrupt"), this,
-                            SLOT(interrupt()), 0);
-        menu->addSeparator();
-
         if (entry) {
-            QMenu* convertTo = new QMenu(menu);
-            QMenu* insert = new QMenu(menu);
-            QMenu* insertBefore = new QMenu(menu);
+            //"Convert To" menu
+            QMenu* convertTo = new QMenu(i18n("Convert To"));
+            convertTo->setIcon(QIcon::fromTheme(QLatin1String("gtk-convert")));
+            menu->addMenu(convertTo);
+
+            if (entry->type() != CommandEntry::Type)
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command"), entry, &WorksheetEntry::convertToCommandEntry);
+
+            if (entry->type() != TextEntry::Type)
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text"), entry, &WorksheetEntry::convertToTextEntry);
 
-            convertTo->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command Entry"), entry, &WorksheetEntry::convertToCommandEntry);
-            convertTo->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text Entry"), entry, &WorksheetEntry::convertToTextEntry);
     #ifdef Discount_FOUND
-            convertTo->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown Entry"), entry, &WorksheetEntry::convertToMarkdownEntry);
+            if (entry->type() != MarkdownEntry::Type)
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown"), entry, &WorksheetEntry::convertToMarkdownEntry);
     #endif
     #ifdef WITH_EPS
-            convertTo->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX Entry"), entry, &WorksheetEntry::convertToLatexEntry);
+            if (entry->type() != LatexEntry::Type)
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), entry, &WorksheetEntry::convertToLatexEntry);
     #endif
-            convertTo->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), entry, &WorksheetEntry::convertToImageEntry);
-            convertTo->addAction(QIcon::fromTheme(QLatin1String("go-next-view-page")), i18n("Page Break"), entry, &WorksheetEntry::converToPageBreakEntry);
-            convertTo->addAction(QIcon(), i18n("Horizontal Line"), entry, &WorksheetEntry::convertToHorizontalRuleEntry);
-            convertTo->addAction(QIcon(), i18n("Hierarchy Entry"), entry, &WorksheetEntry::convertToHierarchyEntry);
+            if (entry->type() != ImageEntry::Type)
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), entry, &WorksheetEntry::convertToImageEntry);
 
-            insert->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command Entry"), entry, SLOT(insertCommandEntry()));
-            insert->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text Entry"), entry, SLOT(insertTextEntry()));
+            if (entry->type() != PageBreakEntry::Type)
+                convertTo->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), entry, &WorksheetEntry::converToPageBreakEntry);
+
+            if (entry->type() != HorizontalRuleEntry::Type)
+                convertTo->addAction(QIcon(), i18n("Horizontal Line"), entry, &WorksheetEntry::convertToHorizontalRuleEntry);
+
+            if (entry->type() != HierarchyEntry::Type)
+                convertTo->addAction(QIcon(), i18n("Hierarchy Entry"), entry, &WorksheetEntry::convertToHierarchyEntry);
+
+            //"Insert After" menu
+            QMenu* insert = new QMenu(i18n("Insert After"), menu);
+            insert->setIcon(QIcon::fromTheme(QLatin1String("edit-table-insert-row-below")));
+            menu->addSeparator();
+            menu->addMenu(insert);
+
+            insert->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command"), entry, SLOT(insertCommandEntry()));
+            insert->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text"), entry, SLOT(insertTextEntry()));
     #ifdef Discount_FOUND
-            insert->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown Entry"), entry, SLOT(insertMarkdownEntry()));
+            insert->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown"), entry, SLOT(insertMarkdownEntry()));
     #endif
     #ifdef WITH_EPS
-            insert->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX Entry"), entry, SLOT(insertLatexEntry()));
+            insert->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), entry, SLOT(insertLatexEntry()));
     #endif
             insert->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), entry, SLOT(insertImageEntry()));
-            insert->addAction(QIcon::fromTheme(QLatin1String("go-next-view-page")), i18n("Page Break"), entry, SLOT(insertPageBreakEntry()));
+            insert->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), entry, SLOT(insertPageBreakEntry()));
             insert->addAction(QIcon(), i18n("Horizontal Line"), entry, SLOT(insertHorizontalRuleEntry()));
             insert->addAction(QIcon(), i18n("Hierarchy Entry"), entry, SLOT(insertHierarchyEntry()));
 
-            insertBefore->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command Entry"), entry, SLOT(insertCommandEntryBefore()));
-            insertBefore->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text Entry"), entry, SLOT(insertTextEntryBefore()));
+            //"Insert Before" menu
+            QMenu* insertBefore = new QMenu(i18n("Insert Before"), menu);
+            insertBefore->setIcon(QIcon::fromTheme(QLatin1String("edit-table-insert-row-above")));
+            menu->addMenu(insertBefore);
+
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command"), entry, SLOT(insertCommandEntryBefore()));
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text"), entry, SLOT(insertTextEntryBefore()));
     #ifdef Discount_FOUND
-            insertBefore->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown Entry"), entry, SLOT(insertMarkdownEntryBefore()));
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown"), entry, SLOT(insertMarkdownEntryBefore()));
     #endif
     #ifdef WITH_EPS
-            insertBefore->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX Entry"), entry, SLOT(insertLatexEntryBefore()));
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), entry, SLOT(insertLatexEntryBefore()));
     #endif
             insertBefore->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), entry, SLOT(insertImageEntryBefore()));
-            insertBefore->addAction(QIcon::fromTheme(QLatin1String("go-next-view-page")), i18n("Page Break"), entry, SLOT(insertPageBreakEntryBefore()));
+            insertBefore->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), entry, SLOT(insertPageBreakEntryBefore()));
             insertBefore->addAction(QIcon(), i18n("Horizontal Line"), entry, SLOT(insertHorizontalRuleEntryBefore()));
             insertBefore->addAction(QIcon(), i18n("Hierarchy Entry"), entry, SLOT(insertHierarchyEntryBefore()));
-
-            convertTo->setTitle(i18n("Convert Entry To"));
-            convertTo->setIcon(QIcon::fromTheme(QLatin1String("gtk-convert")));
-            insert->setTitle(i18n("Insert Entry After"));
-            insert->setIcon(QIcon::fromTheme(QLatin1String("edit-table-insert-row-below")));
-            insertBefore->setTitle(i18n("Insert Entry Before"));
-            insertBefore->setIcon(QIcon::fromTheme(QLatin1String("edit-table-insert-row-above")));
-
-            menu->addMenu(convertTo);
-            menu->addMenu(insert);
-            menu->addMenu(insertBefore);
         } else {
-            menu->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Insert Command Entry"), this, SLOT(appendCommandEntry()));
-            menu->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Insert Text Entry"), this, SLOT(appendTextEntry()));
+            QMenu* insertMenu = new QMenu(i18n("Insert"));
+            insertMenu->setIcon(QIcon::fromTheme(QLatin1String("insert-table-row")));
+
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("run-build")), i18n("Command"), this, SLOT(appendCommandEntry()));
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("draw-text")), i18n("Text"), this, &Worksheet::appendTextEntry);
     #ifdef Discount_FOUND
-            menu->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Insert Markdown Entry"), this, SLOT(appendMarkdownEntry()));
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("text-x-markdown")), i18n("Markdown"), this, &Worksheet::appendMarkdownEntry);
     #endif
     #ifdef WITH_EPS
-            menu->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("Insert LaTeX Entry"), this, SLOT(appendLatexEntry()));
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("text-x-tex")), i18n("LaTeX"), this, &Worksheet::appendLatexEntry);
     #endif
-            menu->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Insert Image"), this, SLOT(appendImageEntry()));
-            menu->addAction(QIcon::fromTheme(QLatin1String("go-next-view-page")), i18n("Insert Page Break"), this, SLOT(appendPageBreakEntry()));
-            menu->addAction(QIcon(), i18n("Insert Horizontal Line"), this, &Worksheet::appendHorizontalRuleEntry);
-            menu->addAction(QIcon(), i18n("Insert Hierarchy Entry"), this, &Worksheet::appendHierarchyEntry);
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("image-x-generic")), i18n("Image"), this, &Worksheet::appendImageEntry);
+            insertMenu->addAction(QIcon::fromTheme(QLatin1String("insert-page-break")), i18n("Page Break"), this, &Worksheet::appendPageBreakEntry);
+            insertMenu->addAction(QIcon(), i18n("Horizontal Line"), this, &Worksheet::appendHorizontalRuleEntry);
+            insertMenu->addAction(QIcon(), i18n("Hierarchy Entry"), this, &Worksheet::appendHierarchyEntry);
+
+            menu->addMenu(insertMenu);
         }
+
+        menu->addSeparator();
+        if (!isRunning())
+            menu->addAction(QIcon::fromTheme(QLatin1String("system-run")), i18n("Evaluate Worksheet"),
+                            this, &Worksheet::evaluate);
+        else
+            menu->addAction(QIcon::fromTheme(QLatin1String("process-stop")), i18n("Interrupt"), this,
+                            &Worksheet::interrupt);
     }
     else
     {
         menu->clear();
-        menu->addAction(QIcon::fromTheme(QLatin1String("go-up")), i18n("Move Entries Up"), this, SLOT(selectionMoveUp()), 0);
-        menu->addAction(QIcon::fromTheme(QLatin1String("go-down")), i18n("Move Entries Down"), this, SLOT(selectionMoveDown()), 0);
-        menu->addAction(QIcon::fromTheme(QLatin1String("media-playback-start")), i18n("Evaluate Entries"), this, SLOT(selectionEvaluate()), 0);
-        menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Remove Entries"), this, SLOT(selectionRemove()), 0);
+        menu->addAction(QIcon::fromTheme(QLatin1String("go-up")), i18n("Move Entries Up"), this, &Worksheet::selectionMoveUp);
+        menu->addAction(QIcon::fromTheme(QLatin1String("go-down")), i18n("Move Entries Down"), this, &Worksheet::selectionMoveDown);
+        menu->addAction(QIcon::fromTheme(QLatin1String("media-playback-start")), i18n("Evaluate Entries"), this, &Worksheet::selectionEvaluate);
+        menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Remove Entries"), this, &Worksheet::selectionRemove);
 
         bool isAnyCommandEntryInSelection = false;
         for (WorksheetEntry* entry : m_selectedEntries)
@@ -2054,147 +2031,147 @@ void Worksheet::keyPressEvent(QKeyEvent *keyEvent)
     QGraphicsScene::keyPressEvent(keyEvent);
 }
 
-void Worksheet::createActions(KActionCollection* collection)
+void Worksheet::setActionCollection(KActionCollection* collection)
+{
+    m_collection = collection;
+}
+
+void Worksheet::initActions()
 {
     // Mostly copied from KRichTextWidget::createActions(KActionCollection*)
     // It would be great if this wasn't necessary.
 
     // Text color
-    QAction * action;
     /* This is "format-stroke-color" in KRichTextWidget */
-    action = new QAction(QIcon::fromTheme(QLatin1String("format-text-color")),
-                         i18nc("@action", "Text &Color..."), collection);
+    auto* action = new QAction(QIcon::fromTheme(QLatin1String("format-text-color")),
+                         i18nc("@action", "Text &Color..."), m_collection);
     action->setIconText(i18nc("@label text color", "Color"));
     action->setPriority(QAction::LowPriority);
     m_richTextActionList.append(action);
-    collection->addAction(QLatin1String("format_text_foreground_color"), action);
-    connect(action, SIGNAL(triggered()), this, SLOT(setTextForegroundColor()));
+    connect(action, &QAction::triggered, this, &Worksheet::setTextForegroundColor);
 
     // Text color
     action = new QAction(QIcon::fromTheme(QLatin1String("format-fill-color")),
-                         i18nc("@action", "Text &Highlight..."), collection);
+                         i18nc("@action", "Text &Highlight..."), m_collection);
     action->setPriority(QAction::LowPriority);
     m_richTextActionList.append(action);
-    collection->addAction(QLatin1String("format_text_background_color"), action);
-    connect(action, SIGNAL(triggered()), this, SLOT(setTextBackgroundColor()));
+    connect(action, &QAction::triggered, this, &Worksheet::setTextBackgroundColor);
 
     // Font Family
-    m_fontAction = new KFontAction(i18nc("@action", "&Font"), collection);
+    m_fontAction = new KFontAction(i18nc("@action", "&Font"), m_collection);
     m_richTextActionList.append(m_fontAction);
-    collection->addAction(QLatin1String("format_font_family"), m_fontAction);
-    connect(m_fontAction, SIGNAL(triggered(QString)), this,
-            SLOT(setFontFamily(QString)));
+    connect(m_fontAction, &KFontAction::textTriggered, this, &Worksheet::setFontFamily);
 
     // Font Size
-    m_fontSizeAction = new KFontSizeAction(i18nc("@action", "Font &Size"),
-                                           collection);
+    m_fontSizeAction = new KFontSizeAction(i18nc("@action", "Font &Size"), m_collection);
     m_richTextActionList.append(m_fontSizeAction);
-    collection->addAction(QLatin1String("format_font_size"), m_fontSizeAction);
-    connect(m_fontSizeAction, SIGNAL(fontSizeChanged(int)), this,
-            SLOT(setFontSize(int)));
+    connect(m_fontSizeAction, &KFontSizeAction::fontSizeChanged, this, &Worksheet::setFontSize);
 
     // Bold
     m_boldAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-bold")),
                                      i18nc("@action boldify selected text", "&Bold"),
-                                     collection);
+                                     m_collection);
     m_boldAction->setPriority(QAction::LowPriority);
     QFont bold;
     bold.setBold(true);
     m_boldAction->setFont(bold);
     m_richTextActionList.append(m_boldAction);
-    collection->addAction(QLatin1String("format_text_bold"), m_boldAction);
-    collection->setDefaultShortcut(m_boldAction, Qt::CTRL + Qt::Key_B);
-    connect(m_boldAction, SIGNAL(triggered(bool)), this, SLOT(setTextBold(bool)));
+    connect(m_boldAction, &QAction::triggered, this, &Worksheet::setTextBold);
 
     // Italic
     m_italicAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-italic")),
-                                       i18nc("@action italicize selected text",
-                                             "&Italic"),
-                                       collection);
+                                       i18nc("@action italicize selected text", "&Italic"),
+                                       m_collection);
     m_italicAction->setPriority(QAction::LowPriority);
     QFont italic;
     italic.setItalic(true);
     m_italicAction->setFont(italic);
     m_richTextActionList.append(m_italicAction);
-    collection->addAction(QLatin1String("format_text_italic"), m_italicAction);
-    collection->setDefaultShortcut(m_italicAction, Qt::CTRL + Qt::Key_I);
-    connect(m_italicAction, SIGNAL(triggered(bool)), this, SLOT(setTextItalic(bool)));
+    connect(m_italicAction, &QAction::triggered, this, &Worksheet::setTextItalic);
 
     // Underline
     m_underlineAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-underline")),
                                           i18nc("@action underline selected text",
                                                 "&Underline"),
-                                          collection);
+                                          m_collection);
     m_underlineAction->setPriority(QAction::LowPriority);
     QFont underline;
     underline.setUnderline(true);
     m_underlineAction->setFont(underline);
     m_richTextActionList.append(m_underlineAction);
-    collection->addAction(QLatin1String("format_text_underline"), m_underlineAction);
-    collection->setDefaultShortcut(m_underlineAction, Qt::CTRL + Qt::Key_U);
-    connect(m_underlineAction, SIGNAL(triggered(bool)), this, SLOT(setTextUnderline(bool)));
+    connect(m_underlineAction, &QAction::triggered, this, &Worksheet::setTextUnderline);
 
     // Strike
     m_strikeOutAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-strikethrough")),
                                           i18nc("@action", "&Strike Out"),
-                                          collection);
+                                          m_collection);
     m_strikeOutAction->setPriority(QAction::LowPriority);
     m_richTextActionList.append(m_strikeOutAction);
-    collection->addAction(QLatin1String("format_text_strikeout"), m_strikeOutAction);
-    collection->setDefaultShortcut(m_strikeOutAction, Qt::CTRL + Qt::Key_L);
-    connect(m_strikeOutAction, SIGNAL(triggered(bool)), this, SLOT(setTextStrikeOut(bool)));
+    connect(m_strikeOutAction, &QAction::triggered, this, &Worksheet::setTextStrikeOut);
 
     // Alignment
-    QActionGroup *alignmentGroup = new QActionGroup(this);
+    auto* alignmentGroup = new QActionGroup(this);
 
     //   Align left
     m_alignLeftAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-justify-left")),
                                           i18nc("@action", "Align &Left"),
-                                          collection);
+                                          m_collection);
     m_alignLeftAction->setPriority(QAction::LowPriority);
     m_alignLeftAction->setIconText(i18nc("@label left justify", "Left"));
     m_richTextActionList.append(m_alignLeftAction);
-    collection->addAction(QLatin1String("format_align_left"), m_alignLeftAction);
-    connect(m_alignLeftAction, SIGNAL(triggered()), this,
-            SLOT(setAlignLeft()));
+    connect(m_alignLeftAction, &QAction::triggered, this, &Worksheet::setAlignLeft);
     alignmentGroup->addAction(m_alignLeftAction);
 
      //   Align center
     m_alignCenterAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-justify-center")),
                                             i18nc("@action", "Align &Center"),
-                                            collection);
+                                            m_collection);
     m_alignCenterAction->setPriority(QAction::LowPriority);
     m_alignCenterAction->setIconText(i18nc("@label center justify", "Center"));
     m_richTextActionList.append(m_alignCenterAction);
-    collection->addAction(QLatin1String("format_align_center"), m_alignCenterAction);
-    connect(m_alignCenterAction, SIGNAL(triggered()), this,
-            SLOT(setAlignCenter()));
+    connect(m_alignCenterAction, &QAction::triggered, this, &Worksheet::setAlignCenter);
     alignmentGroup->addAction(m_alignCenterAction);
 
     //   Align right
     m_alignRightAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-justify-right")),
                                            i18nc("@action", "Align &Right"),
-                                           collection);
+                                           m_collection);
     m_alignRightAction->setPriority(QAction::LowPriority);
     m_alignRightAction->setIconText(i18nc("@label right justify", "Right"));
     m_richTextActionList.append(m_alignRightAction);
-    collection->addAction(QLatin1String("format_align_right"), m_alignRightAction);
-    connect(m_alignRightAction, SIGNAL(triggered()), this,
-            SLOT(setAlignRight()));
+    connect(m_alignRightAction, &QAction::triggered, this, &Worksheet::setAlignRight);
     alignmentGroup->addAction(m_alignRightAction);
 
     //   Align justify
     m_alignJustifyAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-justify-fill")),
                                              i18nc("@action", "&Justify"),
-                                             collection);
+                                             m_collection);
     m_alignJustifyAction->setPriority(QAction::LowPriority);
     m_alignJustifyAction->setIconText(i18nc("@label justify fill", "Justify"));
     m_richTextActionList.append(m_alignJustifyAction);
-    collection->addAction(QLatin1String("format_align_justify"), m_alignJustifyAction);
-    connect(m_alignJustifyAction, SIGNAL(triggered()), this,
-            SLOT(setAlignJustify()));
+    connect(m_alignJustifyAction, &QAction::triggered, this, &Worksheet::setAlignJustify);
     alignmentGroup->addAction(m_alignJustifyAction);
 
+    if (m_collection)
+    {
+        m_collection->addAction(QLatin1String("format_text_foreground_color"), action);
+        m_collection->addAction(QLatin1String("format_text_background_color"), action);
+        m_collection->addAction(QLatin1String("format_font_family"), m_fontAction);
+        m_collection->addAction(QLatin1String("format_font_size"), m_fontSizeAction);
+        m_collection->addAction(QLatin1String("format_text_bold"), m_boldAction);
+        m_collection->setDefaultShortcut(m_boldAction, Qt::CTRL + Qt::Key_B);
+        m_collection->addAction(QLatin1String("format_text_italic"), m_italicAction);
+        m_collection->setDefaultShortcut(m_italicAction, Qt::CTRL + Qt::Key_I);
+        m_collection->addAction(QLatin1String("format_text_underline"), m_underlineAction);
+        m_collection->setDefaultShortcut(m_underlineAction, Qt::CTRL + Qt::Key_U);
+        m_collection->addAction(QLatin1String("format_text_strikeout"), m_strikeOutAction);
+        m_collection->setDefaultShortcut(m_strikeOutAction, Qt::CTRL + Qt::Key_L);
+        m_collection->addAction(QLatin1String("format_align_left"), m_alignLeftAction);
+        m_collection->addAction(QLatin1String("format_align_center"), m_alignCenterAction);
+        m_collection->addAction(QLatin1String("format_align_right"), m_alignRightAction);
+        m_collection->addAction(QLatin1String("format_align_justify"), m_alignJustifyAction);
+    }
+
      /*
      // List style
      KSelectAction* selAction;
@@ -2215,9 +2192,9 @@ void Worksheet::createActions(KActionCollection* collection)
      m_richTextActionList.append(action);
      collection->addAction("format_list_style", action);
      connect(action, SIGNAL(triggered(int)),
-             this, SLOT(_k_setListStyle(int)));
-     connect(action, SIGNAL(triggered()),
-             this, SLOT(_k_updateMiscActions()));
+             this, &Worksheet::_k_setListStyle(int)));
+     connect(action, &QAction::triggered,
+             this, &Worksheet::_k_updateMiscActions()));
 
      // Indent
      action = new QAction(QIcon::fromTheme("format-indent-more"),
@@ -2225,10 +2202,10 @@ void Worksheet::createActions(KActionCollection* collection)
      action->setPriority(QAction::LowPriority);
      m_richTextActionList.append(action);
      collection->addAction("format_list_indent_more", action);
-     connect(action, SIGNAL(triggered()),
-             this, SLOT(indentListMore()));
-     connect(action, SIGNAL(triggered()),
-             this, SLOT(_k_updateMiscActions()));
+     connect(action, &QAction::triggered,
+             this, &Worksheet::indentListMore()));
+     connect(action, &QAction::triggered,
+             this, &Worksheet::_k_updateMiscActions()));
 
      // Dedent
      action = new QAction(QIcon::fromTheme("format-indent-less"),
@@ -2236,8 +2213,8 @@ void Worksheet::createActions(KActionCollection* collection)
      action->setPriority(QAction::LowPriority);
      m_richTextActionList.append(action);
      collection->addAction("format_list_indent_less", action);
-     connect(action, SIGNAL(triggered()), this, SLOT(indentListLess()));
-     connect(action, SIGNAL(triggered()), this, SLOT(_k_updateMiscActions()));
+     connect(action, &QAction::triggered, this, &Worksheet::indentListLess()));
+     connect(action, &QAction::triggered, this, &Worksheet::_k_updateMiscActions()));
      */
 }
 
@@ -2337,6 +2314,9 @@ void Worksheet::paste() {
 
 void Worksheet::setRichTextInformation(const RichTextInfo& info)
 {
+    if (!m_boldAction)
+        initActions();
+
     m_boldAction->setChecked(info.bold);
     m_italicAction->setChecked(info.italic);
     m_underlineAction->setChecked(info.underline);
@@ -2358,8 +2338,8 @@ void Worksheet::setRichTextInformation(const RichTextInfo& info)
 void Worksheet::setAcceptRichText(bool b)
 {
     if (!m_readOnly)
-        for(QAction * action : m_richTextActionList)
-            action->setEnabled(b);
+        for(auto* action : m_richTextActionList)
+            action->setVisible(b);
 }
 
 WorksheetTextItem* Worksheet::currentTextItem()
@@ -2467,7 +2447,7 @@ void Worksheet::registerShortcut(QAction* action)
     for (auto& shortcut : action->shortcuts())
         m_shortcuts.insert(shortcut, action);
 
-    connect(action, SIGNAL(changed()), this, SLOT(updateShortcut()));
+    connect(action, &QAction::changed, this, &Worksheet::updateShortcut);
 }
 
 void Worksheet::updateShortcut()
@@ -2488,7 +2468,6 @@ void Worksheet::updateShortcut()
 
 void Worksheet::dragEnterEvent(QGraphicsSceneDragDropEvent* event)
 {
-    qDebug() << "enter";
     if (m_dragEntry)
         event->accept();
     else
@@ -2502,7 +2481,6 @@ void Worksheet::dragLeaveEvent(QGraphicsSceneDragDropEvent* event)
         return;
     }
 
-    qDebug() << "leave";
     event->accept();
     if (m_placeholderEntry) {
         m_placeholderEntry->startRemoving();
@@ -2775,7 +2753,7 @@ void Worksheet::changeEntryType(WorksheetEntry* target, int newType)
 
 bool Worksheet::isValidEntry(WorksheetEntry* entry)
 {
-    for (WorksheetEntry* iter = firstEntry(); iter; iter = iter->next())
+    for (auto* iter = firstEntry(); iter; iter = iter->next())
         if (entry == iter)
             return true;
 
@@ -2784,7 +2762,7 @@ bool Worksheet::isValidEntry(WorksheetEntry* entry)
 
 void Worksheet::selectionRemove()
 {
-    for (WorksheetEntry* entry : m_selectedEntries)
+    for (auto* entry : m_selectedEntries)
         if (isValidEntry(entry))
             entry->startRemoving();
 
@@ -2941,7 +2919,6 @@ WorksheetEntry * Worksheet::cutSubentriesForHierarchy(HierarchyEntry* hierarchyE
     WorksheetEntry* cutBegin = hierarchyEntry->next();
     WorksheetEntry* cutEnd = cutBegin;
 
-
     bool isCutEnd = false;
     int level = (int)hierarchyEntry->level();
     while (!isCutEnd && cutEnd && cutEnd->next())
